@@ -3,8 +3,23 @@ use Moose;
 use namespace::autoclean;
 use Carp;
 
+our $VERSION = "0.01";
+eval $VERSION;
+
 # ABSTRACT: A simple reflector class for Form::Sensible
 
+=head2 $self->with_trigger
+
+Add a submit button to the form.  Defaults to 0.
+
+=cut
+
+#has 'with_trigger' => (
+#    is => 'rw',
+#    lazy => 1,
+#    default => 0,
+#);
+
 sub reflect_from {
     my ( $self, $handle, $options) = @_;
 
@@ -36,10 +51,9 @@ sub reflect_from {
         $form->add_field( $field_def );
     }
     
-    ## convenience - add a submit button
-    ##my $submit_button = Form::Sensible::Field::Trigger->new( name => 'submit' );
-    ##$form->add_field($submit_button);
-    #warn "Form in create_form: " . Dumper $form;
+    if (exists($options->{'with_trigger'}) && $options->{'with_trigger'}) {
+        $form->add_field(Form::Sensible::Field::Trigger->new( name => 'submit' ));
+    }
     return $self->finalize_form($form, $handle);
 }
 
